@@ -719,7 +719,7 @@ typedef enum {
 	HTML_TABLE_WIDTH,
 	HTML_TABLE_BGCOLOR,
 	HTML_TABLE_BGPIXMAP,
-	HTML_TABLE_ALIGN,
+	HTML_TABLE_ALIGN
 } HTMLTableAttrType;
 
 union _HTMLTableUndoAttr {
@@ -840,8 +840,12 @@ static void
 table_set_bg_color_undo_action (HTMLEngine *e, HTMLUndoData *undo_data, HTMLUndoDirection dir, guint position_after)
 {
 	HTMLTableSetAttrUndo *data = (HTMLTableSetAttrUndo *) undo_data;
+	HTMLTable *table = html_engine_get_table (e);
 
-	table_set_bg_color (e, html_engine_get_table (e), data->attr.color.has_bg_color
+	if (!table)
+		return;
+
+	table_set_bg_color (e, table, data->attr.color.has_bg_color
 			    ? &data->attr.color.color : NULL, html_undo_direction_reverse (dir));
 }
 
@@ -1051,6 +1055,10 @@ table_set_align (HTMLEngine *e, HTMLTable *t, HTMLHAlignType align, HTMLUndoDire
 {
 	HTMLTableSetAttrUndo *undo;
 
+	/* table gone */
+	if (!t)
+		return;
+
 	g_return_if_fail (HTML_OBJECT (t)->parent);
 
 	undo = attr_undo_new (HTML_TABLE_ALIGN);
