@@ -88,7 +88,7 @@ free_color (HTMLPainter *painter,
 
 
 static void
-begin (HTMLPainter *painter, int x1, int y1, int x2, int y2)
+begin (HTMLPainter *painter, gint x1, gint y1, gint x2, gint y2)
 {
 	HTMLGdkPainter *gdk_painter;
 
@@ -99,10 +99,9 @@ begin (HTMLPainter *painter, int x1, int y1, int x2, int y2)
 
 	set_clip_rectangle (painter, 0, 0, 0, 0);
 
-	if (gdk_painter->double_buffer){
-		const int width = x2 - x1 + 1;
-		const int height = y2 - y1 + 1;
-
+	if (gdk_painter->double_buffer) {
+		const gint width = x2 - x1 + 1;
+		const gint height = y2 - y1 + 1;
 
 		/* FIXME: Ideally it should be NULL before coming here. */
 		if (gdk_painter->pixmap && gdk_painter->pixmap != gdk_painter->window)
@@ -114,7 +113,7 @@ begin (HTMLPainter *painter, int x1, int y1, int x2, int y2)
 		gdk_painter->x2 = x2;
 		gdk_painter->y2 = y2;
 
-		if (gdk_painter->set_background){
+		if (gdk_painter->set_background) {
 			gdk_gc_set_background (gdk_painter->gc, &gdk_painter->background);
 			gdk_painter->set_background = FALSE;
 		}
@@ -163,7 +162,7 @@ clear (HTMLPainter *painter)
 
 	gdk_painter = HTML_GDK_PAINTER (painter);
 
-	if (! gdk_painter->double_buffer){
+	if (! gdk_painter->double_buffer) {
 		gdk_window_clear (gdk_painter->window);
 	} else {
 		if (gdk_painter->pixmap != NULL)
@@ -442,7 +441,7 @@ draw_background (HTMLPainter *painter,
 
 		gc = gdk_gc_new (gdk_painter->window);
 
-  		if (color || !gdk_pixbuf_get_has_alpha (pixbuf)) {
+		if (color || !gdk_pixbuf_get_has_alpha (pixbuf)) {
 			pixmap = gdk_pixmap_new (gdk_painter->window, dw, dh, -1);
 
 			if (color) {
@@ -472,8 +471,8 @@ draw_background (HTMLPainter *painter,
 			g_object_unref (pixmap);
 			g_object_unref (gc);
 		} else {
-			int incr_x = 0;
-			int incr_y = 0;
+			gint incr_x = 0;
+			gint incr_y = 0;
 
 			cy = paint.y;
 			ch = paint.height;
@@ -574,7 +573,6 @@ draw_pixmap (HTMLPainter *painter,
 		return;
 	}
 
-
 	tmp_pixbuf = gdk_pixbuf_new (GDK_COLORSPACE_RGB,
 				     gdk_pixbuf_get_has_alpha (pixbuf),
 				     gdk_pixbuf_get_bits_per_sample (pixbuf),
@@ -605,13 +603,13 @@ draw_pixmap (HTMLPainter *painter,
 			      255);
 
 	if (color != NULL) {
-		guchar *p, *q;
+		guchar *q;
 		guint i, j;
 
 		n_channels = gdk_pixbuf_get_n_channels (tmp_pixbuf);
-		p = q = gdk_pixbuf_get_pixels (tmp_pixbuf);
+		q = gdk_pixbuf_get_pixels (tmp_pixbuf);
 		for (i = 0; i < paint.height; i++) {
-			p = q;
+			guchar *p = q;
 
 			for (j = 0; j < paint.width; j++) {
 				gint r, g, b, a;
@@ -666,7 +664,7 @@ fill_rect (HTMLPainter *painter,
 }
 
 static gint
-draw_spell_error (HTMLPainter *painter, int x, int y, int width)
+draw_spell_error (HTMLPainter *painter, gint x, gint y, gint width)
 {
 	HTMLGdkPainter *gdk_painter;
 	GdkGCValues values;
@@ -684,6 +682,7 @@ draw_spell_error (HTMLPainter *painter, int x, int y, int width)
 	gdk_draw_line (gdk_painter->pixmap, gdk_painter->gc, x, y, x + width, y);
 	gdk_gc_set_dashes (gdk_painter->gc, 0, dash_list, 2);
 	gdk_draw_line (gdk_painter->pixmap, gdk_painter->gc, x, y + 1, x + width, y + 1);
+	gdk_gc_set_fill (gdk_painter->gc, values.fill);
 	gdk_gc_set_line_attributes (gdk_painter->gc, values.line_width,
 				    values.line_style, values.cap_style, values.join_style);
 
